﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class EnemyController : MonoBehaviour {

	public int maxHitPoints;
	public float damageCounter;
	public GameObject deathEffect;
	public AudioClip hurt;

	private Animator animator;
	private int hitPoints;
	private Vector3 bounce;
	private int maxScore;

	void Awake(){
		animator = GetComponent<Animator> ();
	}

	// Use this for initialization
	void Start () {
		InitializeVariables ();
	}
	
	// Update is called once per frame
	void Update () {
		
	}

	void InitializeVariables(){
		hitPoints = maxHitPoints;
		maxScore = 1000;
	}

	void UpdateAnimationState(){
		if(hitPoints <= 5){
			animator.SetTrigger ("isDamage");
		}
	}

	void OnCollisionEnter2D(Collision2D collision){
		if(collision.relativeVelocity.magnitude > damageCounter){
			hitPoints -= Mathf.RoundToInt(collision.relativeVelocity.magnitude);
			UpdateScoreStatus (Mathf.RoundToInt (collision.relativeVelocity.magnitude));
			if(GameController.instance != null && MusicController.instance != null){
				if(GameController.instance.isMusicOn){
					if (gameObject != null) {
						AudioSource.PlayClipAtPoint (hurt, transform.position);
					}
				}
			}
		}
			

		UpdateAnimationState ();

		if(hitPoints <= 0){
			Death ();

			if(collision.gameObject.CompareTag("Player Bullet")){
				bounce = collision.transform.GetComponent<Rigidbody2D> ().velocity;
				bounce.y = 0f;
				collision.transform.GetComponent<Rigidbody2D> ().velocity = bounce;
			
			}
		}
	}

	void Death(){
		Destroy (gameObject);
		GameObject newDeathEffect = Instantiate (deathEffect, transform.position, Quaternion.identity) as GameObject;
		Destroy (newDeathEffect, 3f);
		if(GameController.instance != null){
			GameController.instance.score += maxScore;
		}
		DisplayScore ();

	}

	void UpdateScoreStatus(int hitScore){
		if(GameController.instance != null){
			GameController.instance.score += hitScore; 
		}
	}

	void DisplayScore(){
		GameObject scoreText = Instantiate (Resources.Load ("Score Text Canvas"), new Vector3(transform.position.x, transform.position.y + 1f), Quaternion.identity) as GameObject;
		scoreText.transform.GetChild (0).transform.GetComponent<Text> ().text = maxScore.ToString ();
		Destroy (scoreText, 2f);
	}
}
